from debug import *
import sys
import traceback

def function_test(param1, param2, param3):
	debug(print_function_parameters=True)

function_test("test_parameter_1", "test_parameter_2", "test_parameter_3")

